@@ -363,7 +363,7 @@ bool CSiteManagerDialog::Create(wxWindow* parent, std::vector<_connected_site>*
 	auto right = new wxBoxSizer(wxVERTICAL);
 	sides->Add(right, 1, wxLEFT|wxGROW, lay.gap);
 
-	m_pNotebook_Site = new CSiteManagerSite(*this, options_);
+	m_pNotebook_Site = new CSiteManagerSite(options_);
 	if (!m_pNotebook_Site->Load(this)) {
 		return false;
 	}
@@ -1128,7 +1128,7 @@ void CSiteManagerDialog::OnSelChanged(wxTreeEvent& evt)
 		m_is_deleting = false;
 	}
 
-#if !defined(__WXMSW__) && wxCHECK_VERSION(3, 2, 1)
+#if !defined(__WXMSW__)
 	auto focused = tree_->GetFocusedItem();
 	if (focused) {
 		tree_->EnsureVisible(focused);
